# Animal ID!

## Categorization

The lists are categorized into several main categories, according to the orders in which they might appear in a valid English sentence (see http://dictionary.cambridge.org/us/grammar/british-grammar/adjectives-order).

Briefly, adjectives must come in a particular order: opinion, size, age, shape, color, origin, material, purpose, or else the sentence will sound strange.

We use these categorizations and this ordering to ensure cluster ID's sound pleasing to the ear.

## Format

All word lists in this directory are alphabetized lists of words consisting of lowercase letters from a-z and underscores only.

Please keep them alphabetized using unix `sort file -o file` command.
There are no automated tests for this because `sort` sorts differently than Python.
